@@ -219,7 +219,7 @@ class Agent(pg.sprite.Sprite):
             home_addresses[self.home][1],
         )
         self.setup_path()
-        print("first path", self.path)
+        #print("first path", self.path)
 
     def setup_path(self):
         if self.visit_index > len(self.schedule):
@@ -334,7 +334,8 @@ class Agent(pg.sprite.Sprite):
 
         # If the agent has reached the end of the path, go to the next one
         if current_tile_index > len(self.path) - 1:  # reached end of path
-            if self.is_going_home:
+            if self.is_going_home and not self.is_home:
+                self.simulation.homes[self.home].add_agent(self)
                 self.is_home = True
             visit_list = self.schedule[self.visit_index][0]
             if len(visit_list) > 1:
@@ -364,7 +365,6 @@ class Agent(pg.sprite.Sprite):
                         ].add_agent(self)
                 except Exception as e:
                     print(e)
-                    exit()
             return
 
             # current tile based on distance traveled
@@ -428,11 +428,11 @@ class Family:
 def generate_schedules(agents):
     """New scheduling algorithm"""
     rng = np.random.default_rng()
-    wb = rng.choice(range(len(building_addresses)), 1000)
-    sb = rng.choice(social_building_ids, 1000)
-    fb = rng.choice(food_building_ids, 1000)
-    fv = rng.integers(5, 10, 1000)
-    wakeup = rng.random(1000) * 4
+    wb = rng.choice(range(len(building_addresses)), 2000)
+    sb = rng.choice(social_building_ids, 2000)
+    fb = rng.choice(food_building_ids, 5000)
+    fv = rng.integers(5, 10, 2000)
+    wakeup = rng.random(2000) * 4
     index = 0
     work_threshold = 6
     social_threshold = 4
